==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Podana nazwa jest za długa",
    "The given web address is too long" : "Podany adres internetowy jest za długi",
    "The given web address is not a valid URL" : "Podany adres internetowy nie jest prawidłowym adresem URL",
    "The given legal notice address is too long" : "Podany adres noty prawnej jest za długi",
    "The given legal notice address is not a valid URL" : "Podany adres noty prawnej nie jest prawidłowym adresem URL",
    "The given privacy policy address is too long" : "Podany adres polityki prywatności jest za długi",
    "The given privacy policy address is not a valid URL" : "Podany adres polityki prywatności nie jest prawidłowym adresem URL",
    "The given slogan is too long" : "Podany slogan jest za długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "Disable-user-theming should be true or false" : "Opcja Wyłącz użytkownika powinna mieć wartość true lub false",
    "Saved" : "Zapisano",
    "Invalid app given" : "Podano nieprawidłową aplikację",
    "Invalid type for setting \"defaultApp\" given" : "Podano nieprawidłowy typ ustawienia \"defaultApp\"",
    "Invalid setting key" : "Nieprawidłowy klucz ustawień",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wysłany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wartość MAX_FILE_SIZE określoną w formularzu HTML",
    "The file was only partially uploaded" : "Plik został wysłany tylko częściowo",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak katalogu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysk",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "No file uploaded" : "Nie wysłano pliku",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Używasz już własnego motywu. Ustawienia aplikacji Theming mogą zostać nadpisane.",
    "Theming" : "Motyw",
    "Appearance and accessibility" : "Wygląd i dostępność",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Moduł PHP \"imagick\" nie jest włączony, pomimo że aplikacja motywu jest. Aby generowanie favicon działało poprawnie, musisz zainstalować i włączyć ten moduł.",
    "Dark theme with high contrast mode" : "Ciemny motyw z trybem wysokiego kontrastu",
    "Enable dark high contrast mode" : "Włącz ciemny tryb wysokiego kontrastu",
    "Similar to the high contrast mode, but with dark colours." : "Podobny do trybu wysokiego kontrastu, ale z ciemnymi kolorami.",
    "Dark theme" : "Ciemny motyw",
    "Enable dark theme" : "Włącz ciemny motyw",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ciemny motyw łagodny dla Twoich oczu, redukując ogólną luminancję i jasność.",
    "System default theme" : "Domyślny motyw systemu",
    "Enable the system default" : "Włącz domyślne ustawienia systemu",
    "Using the default system appearance." : "Korzystanie z domyślnego wyglądu systemu.",
    "Dyslexia font" : "Czcionka dla dyslektyków",
    "Enable dyslexia font" : "Włącz czcionkę dla dyslektyków",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów w czytaniu spowodowanych dysleksją.",
    "High contrast mode" : "Tryb wysokiego kontrastu",
    "Enable high contrast mode" : "Włącz tryb wysokiego kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tryb wysokiego kontrastu ułatwiający nawigację. Jakość obrazu zostanie zmniejszona, celem poprawy przejrzystości.",
    "Light theme" : "Jasny motyw",
    "Enable the default light theme" : "Włącz domyślny jasny motyw",
    "The default light appearance." : "Domyślny jasny wygląd.",
    "Legal notice" : "Nota prawna",
    "Privacy policy" : "Polityka prywatności",
    "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
    "Name" : "Nazwa",
    "Web link" : "Link",
    "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
    "Slogan" : "Slogan",
    "Legal notice link" : "Link do informacji prawnej",
    "Privacy policy link" : "Link do polityki prywatności",
    "Header logo" : "Logo nagłówka",
    "Upload new header logo" : "Wyślij nowe logo nagłówka",
    "Favicon" : "Ikona favicon",
    "Upload new favicon" : "Wyślij nową ikonę favicon",
    "User settings" : "Ustawienia użytkownika",
    "Disable user theming" : "Wyłącz motywy użytkownika",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Chociaż możesz wybrać i dostosować swoją instancję, użytkownicy mogą zmieniać swoje tło i kolory. Jeśli chcesz wymusić dostosowanie, możesz to włączyć.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motyw umożliwia na łatwą personalizację wyglądu instancji i wspieranych klientów. Ustawiony wygląd będzie widoczny dla wszystkich użytkowników.",
    "Upload new logo" : "Wyślij nowe logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Wyślij nowe tło i obraz logowania",
    "Background and login image" : "Obraz tła i logowania",
    "Advanced options" : "Opcje zaawansowane",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie ImageMagick PHP z obsługą obrazów SVG, aby automatycznie generować favikony na podstawie przesłanego logo i koloru.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}naszego zespołu projektowego{linkend}!",
    "Enable blur background filter (may increase GPU load)" : "Włącz filtr rozmycia tła (może zwiększyć obciążenie GPU)",
    "Customization has been disabled by your administrator" : "Dostosowanie zostało wyłączone przez administratora",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "W niektórych przypadkach skróty klawiaturowe mogą kolidować z narzędziami ułatwień dostępu. Aby umożliwić prawidłowe skupienie się na narzędziu, możesz tutaj wyłączyć wszystkie skróty klawiaturowe. Spowoduje to również wyłączenie wszystkich dostępnych skrótów w aplikacjach.",
    "Disable all keyboard shortcuts" : "Wyłącz wszystkie skróty klawiaturowe",
    "Current selected app: {app}, position {position} of {total}" : "Aktualnie wybrana aplikacja: {app}, pozycja {position} z {total}",
    "Move up" : "Przenieś wyżej",
    "Move down" : "Przenieś niżej",
    "Select a background from your files" : "Wybierz tło ze swoich Plików",
    "Select background" : "Wybierz tło",
    "No background has been selected" : "Nie wybrano tła",
    "Custom background" : "Tło niestandardowe",
    "Plain background" : "Zwykłe tło",
    "Default background" : "Tło domyślne",
    "Theme selection is enforced" : "Wybór motywu jest wymuszony",
    "Could not set the app order" : "Nie można ustawić kolejności aplikacji",
    "Could not reset the app order" : "Nie można zresetować kolejności aplikacji",
    "Navigation bar settings" : "Ustawienia paska nawigacji",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Możesz skonfigurować kolejność aplikacji używaną na pasku nawigacyjnym. Pierwsza będzie aplikacja domyślna, otwierana po zalogowaniu lub kliknięciu na logo.",
    "The default app can not be changed because it was configured by the administrator." : "Domyślnej aplikacji nie można zmienić, ponieważ została skonfigurowana przez administratora.",
    "The app order was changed, to see it in action you have to reload the page." : "Kolejność aplikacji została zmieniona, aby zobaczyć ją po zmianie, należy ponownie załadować stronę.",
    "Reset default app order" : "Zresetuj domyślną kolejność aplikacji",
    "Could not set global default apps" : "Nie można ustawić globalnych aplikacji domyślnych",
    "Default app" : "Aplikacja domyślna",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Domyślną aplikacją jest aplikacja będąca np. otwierana po zalogowaniu lub kliknięciu logo w menu.",
    "Use custom default app" : "Użyj własnej aplikacji domyślnej",
    "Global default app" : "Globalna aplikacja domyślna",
    "Global default apps" : "Globalne aplikacje domyślne",
    "Default app priority" : "Domyślny priorytet aplikacji",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Jeśli aplikacja nie jest włączona dla użytkownika, używana jest następna aplikacja o niższym priorytecie.",
    "Select a custom color" : "Wybierz kolor niestandardowy",
    "Reset to default" : "Przywróć domyślne",
    "Upload" : "Wyślij",
    "Remove background image" : "Usuń obraz tła",
    "Color" : "Kolor",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    "Background" : "Tło",
    "Set a custom background" : "Ustaw niestandardowe tło",
    "Change color" : "Zmień kolor",
    "No background" : "Bez tła"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Podana nazwa jest za długa",
    "The given web address is too long" : "Podany adres internetowy jest za długi",
    "The given web address is not a valid URL" : "Podany adres internetowy nie jest prawidłowym adresem URL",
    "The given legal notice address is too long" : "Podany adres noty prawnej jest za długi",
    "The given legal notice address is not a valid URL" : "Podany adres noty prawnej nie jest prawidłowym adresem URL",
    "The given privacy policy address is too long" : "Podany adres polityki prywatności jest za długi",
    "The given privacy policy address is not a valid URL" : "Podany adres polityki prywatności nie jest prawidłowym adresem URL",
    "The given slogan is too long" : "Podany slogan jest za długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "Disable-user-theming should be true or false" : "Opcja Wyłącz użytkownika powinna mieć wartość true lub false",
    "Saved" : "Zapisano",
    "Invalid app given" : "Podano nieprawidłową aplikację",
    "Invalid type for setting \"defaultApp\" given" : "Podano nieprawidłowy typ ustawienia \"defaultApp\"",
    "Invalid setting key" : "Nieprawidłowy klucz ustawień",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wysłany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wartość MAX_FILE_SIZE określoną w formularzu HTML",
    "The file was only partially uploaded" : "Plik został wysłany tylko częściowo",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak katalogu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysk",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "No file uploaded" : "Nie wysłano pliku",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Używasz już własnego motywu. Ustawienia aplikacji Theming mogą zostać nadpisane.",
    "Theming" : "Motyw",
    "Appearance and accessibility" : "Wygląd i dostępność",
    "PHP Imagick module" : "Moduł PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Moduł PHP \"imagick\" nie jest włączony, pomimo że aplikacja motywu jest. Aby generowanie favicon działało poprawnie, musisz zainstalować i włączyć ten moduł.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Moduł PHP \"imagick\" w tym przypadku nie obsługuje SVG. Dla lepszej kompatybilności zaleca się jego instalację.",
    "Dark theme with high contrast mode" : "Ciemny motyw z trybem wysokiego kontrastu",
    "Enable dark high contrast mode" : "Włącz ciemny tryb wysokiego kontrastu",
    "Similar to the high contrast mode, but with dark colours." : "Podobny do trybu wysokiego kontrastu, ale z ciemnymi kolorami.",
    "Dark theme" : "Ciemny motyw",
    "Enable dark theme" : "Włącz ciemny motyw",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ciemny motyw łagodny dla Twoich oczu, redukując ogólną luminancję i jasność.",
    "System default theme" : "Domyślny motyw systemu",
    "Enable the system default" : "Włącz domyślne ustawienia systemu",
    "Using the default system appearance." : "Korzystanie z domyślnego wyglądu systemu.",
    "Dyslexia font" : "Czcionka dla dyslektyków",
    "Enable dyslexia font" : "Włącz czcionkę dla dyslektyków",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów w czytaniu spowodowanych dysleksją.",
    "High contrast mode" : "Tryb wysokiego kontrastu",
    "Enable high contrast mode" : "Włącz tryb wysokiego kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tryb wysokiego kontrastu ułatwiający nawigację. Jakość obrazu zostanie zmniejszona, celem poprawy przejrzystości.",
    "Light theme" : "Jasny motyw",
    "Enable the default light theme" : "Włącz domyślny jasny motyw",
    "The default light appearance." : "Domyślny jasny wygląd.",
    "Legal notice" : "Nota prawna",
    "Privacy policy" : "Polityka prywatności",
    "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
    "Name" : "Nazwa",
    "Web link" : "Link",
    "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
    "Slogan" : "Slogan",
    "Primary color" : "Kolor podstawowy",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Kolor podstawowy jest używany do wyróżniania elementów, takich jak ważne przyciski. Może być lekko dostosowany w zależności od bieżącego schematu kolorów.",
    "Legal notice link" : "Link do informacji prawnej",
    "Privacy policy link" : "Link do polityki prywatności",
    "Header logo" : "Logo nagłówka",
    "Upload new header logo" : "Wyślij nowe logo nagłówka",
    "Favicon" : "Ikona favicon",
    "Upload new favicon" : "Wyślij nową ikonę favicon",
    "User settings" : "Ustawienia użytkownika",
    "Disable user theming" : "Wyłącz motywy użytkownika",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Chociaż możesz wybrać i dostosować swoją instancję, użytkownicy mogą zmieniać swoje tło i kolory. Jeśli chcesz wymusić dostosowanie, możesz to włączyć.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motyw umożliwia na łatwą personalizację wyglądu instancji i wspieranych klientów. Ustawiony wygląd będzie widoczny dla wszystkich użytkowników.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Zamiast obrazu tła możesz również ustawić jednolity kolor tła. Jeśli używasz obrazu tła, zmiana tego koloru wpłynie na kolor ikon w menu aplikacji.",
    "Background color" : "Kolor tła",
    "Upload new logo" : "Wyślij nowe logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Wyślij nowe tło i obraz logowania",
    "Background and login image" : "Obraz tła i logowania",
    "Advanced options" : "Opcje zaawansowane",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie ImageMagick PHP z obsługą obrazów SVG, aby automatycznie generować favikony na podstawie przesłanego logo i koloru.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalna dostępność jest dla nas bardzo ważna. Przestrzegamy standardów sieciowych i dbamy, aby wszystko było używalne także bez myszy, jak również z oprogramowaniem wspomagającym, takim jak czytniki ekranu. Dążymy do zgodności z Wytycznymi dotyczącymi {linkstart} dostępności treści internetowych (WCAG) {linkend} 2.1 na poziomie AA, a w przypadku motywów o wysokim kontraście nawet na poziomie AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}naszego zespołu projektowego{linkend}!",
    "Unable to apply the setting." : "Nie można zastosować ustawienia.",
    "Appearance and accessibility settings" : "Ustawienia wyglądu i dostępności",
    "Misc accessibility options" : "Inne opcje dostępności",
    "Enable blur background filter (may increase GPU load)" : "Włącz filtr rozmycia tła (może zwiększyć obciążenie GPU)",
    "Customization has been disabled by your administrator" : "Dostosowanie zostało wyłączone przez administratora",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Ustaw kolor podstawowy, aby wyróżnić ważne elementy. Kolor używany dla elementów, takich jak główne przyciski, może się nieco różnić, ponieważ dostosowuje się do wymagań dostępności.",
    "Background and color" : "Tło i kolor",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Tło może być ustawione jako obraz z zestawu domyślnego, przesłany przez użytkownika obraz lub jednolity kolor.",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "W niektórych przypadkach skróty klawiaturowe mogą kolidować z narzędziami ułatwień dostępu. Aby umożliwić prawidłowe skupienie się na narzędziu, możesz tutaj wyłączyć wszystkie skróty klawiaturowe. Spowoduje to również wyłączenie wszystkich dostępnych skrótów w aplikacjach.",
    "Disable all keyboard shortcuts" : "Wyłącz wszystkie skróty klawiaturowe",
    "Current selected app: {app}, position {position} of {total}" : "Aktualnie wybrana aplikacja: {app}, pozycja {position} z {total}",
    "Move up" : "Przenieś wyżej",
    "Move down" : "Przenieś niżej",
    "Select a background from your files" : "Wybierz tło ze swoich Plików",
    "Select background" : "Wybierz tło",
    "No background has been selected" : "Nie wybrano tła",
    "Custom background" : "Tło niestandardowe",
    "Plain background" : "Zwykłe tło",
    "Default background" : "Tło domyślne",
    "Theme selection is enforced" : "Wybór motywu jest wymuszony",
    "Could not set the app order" : "Nie można ustawić kolejności aplikacji",
    "Could not reset the app order" : "Nie można zresetować kolejności aplikacji",
    "Navigation bar settings" : "Ustawienia paska nawigacji",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Możesz skonfigurować kolejność aplikacji używaną na pasku nawigacyjnym. Pierwsza będzie aplikacja domyślna, otwierana po zalogowaniu lub kliknięciu na logo.",
    "The default app can not be changed because it was configured by the administrator." : "Domyślnej aplikacji nie można zmienić, ponieważ została skonfigurowana przez administratora.",
    "The app order was changed, to see it in action you have to reload the page." : "Kolejność aplikacji została zmieniona, aby zobaczyć ją po zmianie, należy ponownie załadować stronę.",
    "Reset default app order" : "Zresetuj domyślną kolejność aplikacji",
    "Could not set primary color" : "Nie udało się ustawić podstawowego koloru",
    "Reset primary color" : "Resetuj kolor podstawowy",
    "Could not set global default apps" : "Nie można ustawić globalnych aplikacji domyślnych",
    "Default app" : "Aplikacja domyślna",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Domyślną aplikacją jest aplikacja będąca np. otwierana po zalogowaniu lub kliknięciu logo w menu.",
    "Use custom default app" : "Użyj własnej aplikacji domyślnej",
    "Global default app" : "Globalna aplikacja domyślna",
    "Global default apps" : "Globalne aplikacje domyślne",
    "Default app priority" : "Domyślny priorytet aplikacji",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Jeśli aplikacja nie jest włączona dla użytkownika, używana jest następna aplikacja o niższym priorytecie.",
    "Select a custom color" : "Wybierz kolor niestandardowy",
    "Reset to default" : "Przywróć domyślne",
    "Upload" : "Wyślij",
    "Remove background image" : "Usuń obraz tła",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    ". Unable to apply the setting." : ". Nie udało się zapisać ustawień."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
